@@ -1,28 +1,29 @@
 context("extract_smap")
 
 test_that("invalid datasets cause errors", {
-    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 3)
+    skip_on_cran()
+    files <-  find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
     downloads <- download_smap(files[1, ])
     expect_error(extract_smap(downloads,
-                              name = 'Soil_Moisture_Retrieval_Data/soil_flavor',
+                              name = 'Soil_Moisture_Retrieval_Data_AM/soil_flavor',
                               in_memory = TRUE))
 })
 
 test_that("extract_smap produces a RasterStack", {
     skip_on_cran()
-    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 3)
+    files <-  find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
     downloads <- download_smap(files[1, ])
     r <- extract_smap(downloads,
-                      name = 'Soil_Moisture_Retrieval_Data/soil_moisture',
+                      name = 'Soil_Moisture_Retrieval_Data_AM/soil_moisture',
                       in_memory = TRUE)
     expect_that(r, is_a("RasterStack"))
 })
 
 test_that("-9999 is used fill value when a _FillValue doesn't exist", {
     skip_on_cran()
-    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 3)
+    files <-  find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
     downloads <- download_smap(files)
-    r <- extract_smap(downloads, name = "Soil_Moisture_Retrieval_Data/latitude")
+    r <- extract_smap(downloads, name = "Soil_Moisture_Retrieval_Data_PM/latitude_pm")
     # the fill value in the file is -9999, but there is no fill value attribute
     # therefore, if this function works, the minimum should be >= -90
     # (the latitude at the south pole)
@@ -31,9 +32,9 @@ test_that("-9999 is used fill value when a _FillValue doesn't exist", {
 
 test_that("raster stacks are composed of raster layers", {
     skip_on_cran()
-    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 3)
+    files <-  find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
     downloads <- download_smap(files)
-    r <- extract_smap(downloads, name = "Soil_Moisture_Retrieval_Data/latitude")
+    r <- extract_smap(downloads, name = "Soil_Moisture_Retrieval_Data_AM/latitude")
     expect_that(r[[1]], is_a("RasterLayer"))
 })
 
@@ -60,9 +61,9 @@ test_that("layer names for SPL3FT include file name + am/pm suffix", {
 
 test_that("layer names for SPL3SMP include file name", {
     skip_on_cran()
-    files <- find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 3)
+    files <-  find_smap(id = "SPL3SMP", dates = "2015-03-31", version = 4)
     downloads <- download_smap(files)
-    r <- extract_smap(downloads, name = "Soil_Moisture_Retrieval_Data/latitude")
+    r <- extract_smap(downloads, name = "Soil_Moisture_Retrieval_Data_AM/latitude")
     expected_names <- paste(downloads$name)
     expect_equal(names(r), expected_names)
 })
